diff --git a/src/lib/element_access_type.svelte b/src/lib/e_app_access_type.svelte
similarity index 100%
rename from src/lib/element_access_type.svelte
rename to src/lib/e_app_access_type.svelte
diff --git a/src/lib/element_app_cfg.svelte b/src/lib/e_app_cfg.svelte
similarity index 99%
rename from src/lib/element_app_cfg.svelte
rename to src/lib/e_app_cfg.svelte
index 05fe32aa..3a450666 100644
--- a/src/lib/element_app_cfg.svelte
+++ b/src/lib/e_app_cfg.svelte
@@ -5,7 +5,7 @@ import { RadioGroup, RadioItem } from '@skeletonlabs/skeleton';
import { ae_util } from '$lib/ae_utils/ae_utils';
import { ae_loc, ae_sess, ae_api, slct, slct_trigger } from '$lib/ae_stores';
-import Element_theme from '$lib/element_theme.svelte';
+import Element_theme from '$lib/e_app_theme.svelte';
let notes: null|string = null;
let all: boolean = false;
diff --git a/src/lib/e_app_debug_menu.svelte b/src/lib/e_app_debug_menu.svelte
new file mode 100644
index 00000000..2b5e0ea2
--- /dev/null
+++ b/src/lib/e_app_debug_menu.svelte
@@ -0,0 +1,247 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ Debug
+
+
+
+ {JSON.stringify($ae_loc, null, 2)}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/lib/element_sign_in_out.svelte b/src/lib/e_app_sign_in_out.svelte
similarity index 100%
rename from src/lib/element_sign_in_out.svelte
rename to src/lib/e_app_sign_in_out.svelte
diff --git a/src/lib/e_app_sys_menu.svelte b/src/lib/e_app_sys_menu.svelte
new file mode 100644
index 00000000..fd857bb6
--- /dev/null
+++ b/src/lib/e_app_sys_menu.svelte
@@ -0,0 +1,380 @@
+
+
+
+
+
+
+
+
+
+ {$ae_loc?.person?.full_name ?? '-- not set --'}
+
+
+ {$ae_loc?.user?.username ?? '-- not set --'}
+
+
+ {#if $ae_loc.edit_mode}
+
+ {:else if $ae_loc.authenticated_access}
+
+ {/if}
+
+
diff --git a/src/lib/ae_stores.ts b/src/lib/ae_stores.ts
index 4040dbb9..1b9a9bb1 100644
--- a/src/lib/ae_stores.ts
+++ b/src/lib/ae_stores.ts
@@ -66,9 +66,10 @@ const ae_app_local_data_defaults: key_val = {
iframe: false,
title: `OSIT's Æ`, // - Dev SvelteKit`, // Æ
- debug: false, // A simple flag to know if we should show debug information.
- edit_mode: false, // A simple flag to know if we should show edit mode options.
- sync_local_config: true, // A simple flag to know if we should sync local config with the remote API server.
+ debug_menu: false, // Flag show debug menu.
+ debug_mode: false, // Flag to know if we should be in debug mode and show show debug options.
+ edit_mode: false, // Flag to know if we should be in edit mode and show edit options.
+ sync_local_config: true, // Flag to know if we should sync local config with the remote API server.
'account_id': ae_account_id, // OSIT Demo _XY7DXtc9MY
'account_code': 'not_set',